#ifdef __cplusplus
#error "Do not use C++: this is a C application."
#endif
#if !defined(__GNUC__) || (__GNUC__ < 4)
#define __attribute__(x)
#endif
#if defined(__linux__) || defined(__MINT__)
#define _GNU_SOURCE	/* See test-*.c what needs this. */
#endif
#if !defined(__BEGIN_DECLS)
# define __BEGIN_DECLS
#endif
#if !defined(__END_DECLS)
# define __END_DECLS
#endif
#define HAVE_ARC4RANDOM 1
#define HAVE_CAPSICUM 0
#define HAVE_ERR 1
#define HAVE_EXPLICIT_BZERO 1
#define HAVE_GETPROGNAME 1
#define HAVE_INFTIM 1
#define HAVE_MD5 1
#define HAVE_MEMMEM 1
#define HAVE_MEMRCHR 1
#define HAVE_MEMSET_S 0
#define HAVE_PATH_MAX 1
#define HAVE_PLEDGE 1
#define HAVE_PROGRAM_INVOCATION_SHORT_NAME 0
#define HAVE_REALLOCARRAY 1
#define HAVE_RECALLOCARRAY 1
#define HAVE_SANDBOX_INIT 0
#define HAVE_SECCOMP_FILTER 0
#define HAVE_SOCK_NONBLOCK 1
#define HAVE_STRLCAT 1
#define HAVE_STRLCPY 1
#define HAVE_STRTONUM 1
#define HAVE_SYSTRACE 0
#define HAVE_ZLIB 1
#define HAVE___PROGNAME 1
